# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# Ported by NoMaY from GNURX version to CC-RH version

set(CMAKE_MODULE_PATH "${CMAKE_CURRENT_LIST_DIR}/../../cmake/Modules")

set(CMAKE_SYSTEM_NAME Generic)
set(CMAKE_SYSTEM_PROCESSOR rh850) # It seems that this variable is not used actually by CMake.

# default to Release build
if(NOT CMAKE_BUILD_TYPE)
    set(CMAKE_BUILD_TYPE "Debug" CACHE STRING "Choose the type of build, options are: Debug Release." FORCE)
endif()

set(TOOLCHAIN_EXT ".exe")

find_program(COMPILER_ON_PATH "ccrh${TOOLCHAIN_EXT}")

if(COMPILER_ON_PATH)
    # check on the current path
    get_filename_component(RH850_TOOLCHAIN_PATH ${COMPILER_ON_PATH} DIRECTORY)
    string(REPLACE "/" "\\" _RH850_TOOLCHAIN_PATH "${RH850_TOOLCHAIN_PATH}")
    message(STATUS "Using RH850 CC-RH from path = ${_RH850_TOOLCHAIN_PATH}")
    unset(_RH850_TOOLCHAIN_PATH)
else()
    # not found
    message(NOTICE
        "Error: Unable to find RH850 CC-RH compiler on the PATH = $ENV{Path}"
    )
#    message(FATAL_ERROR "Aborted due to runtime environment error.")
set(RH850_TOOLCHAIN_PATH "C:/Renesas/CS+/CC/CC-RH/V2.04.00/bin")
endif()

#find_program(CONVERTER_ON_PATH "renesas_cc_converter${TOOLCHAIN_EXT}")

#if(CONVERTER_ON_PATH)
#    # check on the current path
#    get_filename_component(RH850_EXTERNAL_TOOLCHAIN_PATH ${CONVERTER_ON_PATH} DIRECTORY)
#    string(REPLACE "/" "\\" _RH850_EXTERNAL_TOOLCHAIN_PATH "${RH850_EXTERNAL_TOOLCHAIN_PATH}")
#    message(STATUS "Using e2 studio's X Converter from path = ${_RH850_EXTERNAL_TOOLCHAIN_PATH}")
#    unset(_RH850_EXTERNAL_TOOLCHAIN_PATH)
#else()
#    # not found
#    message(NOTICE
#        "Warning: Unable to find e2 studio's X Converter on the PATH = $ENV{Path}\n"
#        "Debugging with RH850 GDB is not available when the converter is not executed."
#    )
#endif()

# perform compiler test with the static library
#set(CMAKE_TRY_COMPILE_TARGET_TYPE STATIC_LIBRARY)

set(CMAKE_C_COMPILER    ${RH850_TOOLCHAIN_PATH}/ccrh${TOOLCHAIN_EXT} CACHE STRING "")
#set(CMAKE_CXX_COMPILER  ${RH850_TOOLCHAIN_PATH}/ccrh${TOOLCHAIN_EXT} CACHE STRING "")
set(CMAKE_ASM_COMPILER  ${RH850_TOOLCHAIN_PATH}/asrh${TOOLCHAIN_EXT})
set(CMAKE_LINKER        ${RH850_TOOLCHAIN_PATH}/rlink${TOOLCHAIN_EXT})
set(CMAKE_AR            ${RH850_TOOLCHAIN_PATH}/rlink${TOOLCHAIN_EXT})
#if(RH850_EXTERNAL_TOOLCHAIN_PATH)
#    set(RENESAS_XCONVERTER  ${RH850_EXTERNAL_TOOLCHAIN_PATH}/renesas_cc_converter${TOOLCHAIN_EXT})
#endif()

set(CMAKE_FIND_ROOT_PATH_MODE_PROGRAM NEVER)
set(CMAKE_FIND_ROOT_PATH_MODE_LIBRARY ONLY)
set(CMAKE_FIND_ROOT_PATH_MODE_INCLUDE ONLY)
set(CMAKE_FIND_ROOT_PATH_MODE_PACKAGE ONLY)

set(COMMON_FLAGS    "${CPU_FLAGS} -goptimize -Xcharacter_set=utf8")
set(CMAKE_C_FLAGS 	"${COMMON_FLAGS} -Xasm_option=-Xprn_path -Xpass_source -Xdbl_size=4")
#set(CMAKE_CXX_FLAGS "${COMMON_FLAGS} -Xasm_option=-Xprn_path -Xpass_source -Xdbl_size=4")
set(CMAKE_ASM_FLAGS "${COMMON_FLAGS} -Xprn_path")
set(CMAKE_C_LINK_FLAGS     "")
#set(CMAKE_CXX_LINK_FLAGS   "")
set(SYSLIB_FLAGS "")
foreach (_syslibFile ${SYSLIB_FILES})
    set(SYSLIB_FLAGS "${SYSLIB_FLAGS} -library=\"${RH850_TOOLCHAIN_PATH}/../lib/${_syslibFile}\"")
endforeach()
#message(STATUS "SYSLIB_FLAGS=${SYSLIB_FLAGS}")
set(CMAKE_EXE_LINKER_FLAGS "${SYSLIB_FLAGS} -optimize=symbol_delete -entry=__cstart")
#set(RENESAS_XCONVERTER_FLAGS "")

set(CMAKE_C_COMPILER_ID RENESAS)
set(CMAKE_C_COMPILER_ID_RUN TRUE)
set(CMAKE_C_COMPILER_ARCHITECTURE_ID RH850)
set(CMAKE_C_COMPILER_FORCED TRUE)
#set(CMAKE_CXX_COMPILER_ID RENESAS)
#set(CMAKE_CXX_COMPILER_ID_RUN TRUE)
#set(CMAKE_CXX_COMPILER_ARCHITECTURE_ID RH850)
#set(CMAKE_CXX_COMPILER_FORCED TRUE)
set(CMAKE_ASM_COMPILER_ID RENESAS)
set(CMAKE_ASM_COMPILER_ID_RUN TRUE)
set(CMAKE_ASM_COMPILER_ARCHITECTURE_ID RH850)
set(CMAKE_ASM_COMPILER_FORCED TRUE)
